@@ -20,6 +20,7 @@ class TestToProtoTestList(unittest.TestCase):
 
 
     def test_moduleImportFailure(self):
+        "toProtoTestList() raises import errors normally"
         suite = MagicMock()
         suite.__class__.__name__ = str('ModuleImportFailure')
         suite.__str__.return_value = "exception_method other_stuff"
@@ -27,6 +28,15 @@ class TestToProtoTestList(unittest.TestCase):
         self.assertRaises(AttributeError, loader.toProtoTestList, (suite,))
 
 
+    def test_moduleImportFailureIgnored(self):
+        "toProtoTestList() does not raise errors when doing completions"
+        suite = MagicMock()
+        suite.__class__.__name__ = str('ModuleImportFailure')
+        suite.__str__.return_value = "exception_method other_stuff"
+        suite.exception_method.side_effect = AttributeError
+        self.assertEqual(loader.toProtoTestList(suite, doing_completions=True), [])
+
+
 
 class TestCompletions(unittest.TestCase):
 
@@ -133,6 +143,39 @@ class A(unittest.TestCase):
         shutil.rmtree(tmpdir)
 
 
+    def test_completionIgnoresErrors(self):
+        "Errors in one module don't block the remaining completions"
+        cwd = os.getcwd()
+        tmpdir = tempfile.mkdtemp()
+        os.chdir(tmpdir)
+        os.mkdir('my_pkg2')
+        fh = open(os.path.join('my_pkg2', '__init__.py'), 'w')
+        fh.write('')
+        fh.close()
+        fh = open(os.path.join('my_pkg2', 'test_things.py'), 'w')
+        fh.write(
+"""
+import unittest
+
+class A(unittest.TestCase):
+    def testOne(self):
+        pass
+    def testTwo(self):
+        pass
+""")
+        fh.close()
+        fh = open(os.path.join('my_pkg2', 'test_crash.py'), 'w')
+        fh.write("import moocow")
+        fh.close()
+        c = set(loader.getCompletions('.').split('\n'))
+        self.assertIn('my_pkg2', c)
+        self.assertIn('my_pkg2.test_things', c)
+        self.assertIn('my_pkg2.test_things.A.testOne', c)
+        self.assertIn('my_pkg2.test_things.A.testTwo', c)
+        os.chdir(cwd)
+        shutil.rmtree(tmpdir)
+
+
 
 class TestIsPackage(unittest.TestCase):
 
